==> seedsui-react-5.7.93.tgz: package/lib/Input/Star/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["value", "min", "max", "onChange", "onError"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Star from "./../../Star";
import locale from "./../../locale";
import { jsx as _jsx } from "react/jsx-runtime";
var InputStar = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$value = _ref.value,
    value = _ref$value === void 0 ? 0 : _ref$value,
    _ref$min = _ref.min,
    min = _ref$min === void 0 ? 0 : _ref$min,
    _ref$max = _ref.max,
    max = _ref$max === void 0 ? 5 : _ref$max,
    onChange = _ref.onChange,
    onError = _ref.onError,
    props = _objectWithoutProperties(_ref, _excluded);
  if (typeof max !== 'number' || max <= 0) {
    max = 5;
  }
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  function handleChange(e, newValue) {
    if (newValue < min) {
      if (onError) {
        onError({
          errMsg: locale("\u4E0D\u80FD\u5C0F\u4E8E".concat(min, "\u9897\u661F"), 'hint_cannot_be_less_than_star', [min]),
          min: min,
          value: newValue
        });
        return;
      }
      newValue = min;
    }
    if (onChange) onChange(newValue);
    e.stopPropagation();
  }
  var stars = [];
  for (var i = 1; i <= max; i++) {
    stars.push(i);
  }
  var current = value;
  if (current < min) current = min;
  return /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, props), {}, {
    className: "input-star".concat(props.className ? ' ' + props.className : ''),
    ref: rootRef,
    children: stars.map(function (index) {
      return /*#__PURE__*/_jsx(Star, {
        onClick: function onClick(e) {
          handleChange(e, index);
        },
        className: index <= current ? 'active' : ''
      }, index);
    })
  }));
});
export default InputStar;

==> seedsui-react-5.8.10.tgz: package/lib/Input/Star/index.js <==
var _excluded = ["value", "min", "max", "onChange", "onError"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Star from "./../../Star";
import locale from "./../../locale";
var InputStar = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$value = _ref.value,
    value = _ref$value === void 0 ? 0 : _ref$value,
    _ref$min = _ref.min,
    min = _ref$min === void 0 ? 0 : _ref$min,
    _ref$max = _ref.max,
    max = _ref$max === void 0 ? 5 : _ref$max,
    onChange = _ref.onChange,
    onError = _ref.onError,
    props = _objectWithoutProperties(_ref, _excluded);
  if (typeof max !== 'number' || max <= 0) {
    max = 5;
  }
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  function handleChange(e, newValue) {
    if (newValue < min) {
      if (onError) {
        onError({
          errMsg: locale("\u4E0D\u80FD\u5C0F\u4E8E".concat(min, "\u9897\u661F"), 'hint_cannot_be_less_than_star', [min]),
          min: min,
          value: newValue
        });
        return;
      }
      newValue = min;
    }
    if (onChange) onChange(newValue);
    e.stopPropagation();
  }
  var stars = [];
  for (var i = 1; i <= max; i++) {
    stars.push(i);
  }
  var current = value;
  if (current < min) current = min;
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "input-star".concat(props.className ? ' ' + props.className : ''),
    ref: rootRef
  }), stars.map(function (index) {
    return /*#__PURE__*/React.createElement(Star, {
      onClick: function onClick(e) {
        handleChange(e, index);
      },
      key: index,
      className: index <= current ? 'active' : ''
    });
  }));
});
export default InputStar;
